@@ -122,25 +122,29 @@ PrintPreview.start = function(initialAction, instance) {
         }
     }
 
-    var bbPaper = Print.getPaperBox(doc);
-    bbPaper.growXY(bbPaper.getWidth()/100, bbPaper.getHeight()/100);
-    var bbDoc = doc.getBoundingBox();
-    var positionAccepted = doc.getVariable("PageSettings/PositionAccepted");
-    // check if paper contains drawing:
-    if (!bbPaper.containsBox(bbDoc) && !positionAccepted) {
-        var initialZoom = appWin.property("PrintPreview/InitialZoom");
-        if (initialZoom!=="View" && initialZoom!=="Box") {
-            var ret = QMessageBox.warning(appWin,
-                qsTr("Auto fit"),
-                qsTr("Auto fit drawing to paper?"),
-                buttons);
-            // workaround for Qt keyboard focus bug:
-            appWin.activateWindow();
-            if (ret===QMessageBox.Yes) {
-                appWin.setProperty("PrintPreview/InitialZoom", "Auto");
-            }
-            else {
-                doc.setVariable("PageSettings/PositionAccepted", true);
+    // don't apply global scale for layout blocks:
+    var blockId = doc.getCurrentBlockId();
+    if (!doc.isLayoutBlock(blockId) || blockId===doc.getModelSpaceBlockId()) {
+        var bbPaper = Print.getPaperBox(doc);
+        bbPaper.growXY(bbPaper.getWidth()/100, bbPaper.getHeight()/100);
+        var bbDoc = doc.getBoundingBox();
+        var positionAccepted = doc.getVariable("PageSettings/PositionAccepted");
+        // check if paper contains drawing:
+        if (!bbPaper.containsBox(bbDoc) && !positionAccepted) {
+            var initialZoom = appWin.property("PrintPreview/InitialZoom");
+            if (initialZoom!=="View" && initialZoom!=="Box") {
+                var ret = QMessageBox.warning(appWin,
+                    qsTr("Auto fit"),
+                    qsTr("Auto fit drawing to paper?"),
+                    buttons);
+                // workaround for Qt keyboard focus bug:
+                appWin.activateWindow();
+                if (ret===QMessageBox.Yes) {
+                    appWin.setProperty("PrintPreview/InitialZoom", "Auto");
+                }
+                else {
+                    doc.setVariable("PageSettings/PositionAccepted", true);
+                }
             }
         }
     }
@@ -491,7 +495,12 @@ PrintPreviewImpl.showPageSettings = function() {
     var action = RGuiAction.getByScriptFile("scripts/Edit/DrawingPreferences/DrawingPreferences.js");
     var appWin = EAction.getMainWindow();
     appWin.setProperty("PreferencesPage", "PageSettings");
-    action.trigger();
+
+    // temporarily always force global execution for preferences:
+    var fg = action.getForceGlobal();
+    action.setForceGlobal(true);
+    action.slotTrigger();
+    action.setForceGlobal(fg);
 };
 
 /**
@@ -1099,6 +1108,21 @@ PrintPreviewImpl.prototype.slotAutoZoomToPage = function() {
  * are changed (e.g. offset).
  */
 PrintPreviewImpl.prototype.updateFromPreferences = function() {
+    // 20261212: only if document is current document:
+    // signal is triggered for all documents:
+    var currentDoc = EAction.getDocument();
+    var thisDoc = this.getDocument();
+    if (RSettings.getQtVersion()>=0x060000) {
+        if (currentDoc.__PROXY__.getAddress()!==thisDoc.__PROXY__.getAddress()) {
+            return;
+        }
+    }
+    else {
+        if (currentDoc.toString()!==thisDoc.toString()) {
+            return;
+        }
+    }
+
     this.showUiOptions(true);
     this.updateBackgroundDecoration();
     this.updateBackgroundTransform();
