@@ -19,7 +19,7 @@
 
 include("scripts/EAction.js");
 include("scripts/sprintf.js");
-include("../../WidgetFactory.js");
+include("scripts/WidgetFactory.js");
 
 /**
  * Internal helper class. Notified when properties are changed.
@@ -40,12 +40,9 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
     // only do something if the value has actually changed
     // remember edited status of widgets
 
-//    qDebug("propertyChanged:", value);
-//    qDebug("propertyChanged: sender: ", this.sender);
-
     var attributes = this.propertyEditor.getPropertyAttributes(this.propertyType);
 
-    var typeHint = 0;
+    var typeHint = RS.UnknownType;
 
     // value is a list property (e.g. x coordinate of a vertex of a polyline):
     if (attributes.isList()) {
@@ -61,15 +58,31 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
         return;
     }
 
+    // value is QFont:
+    else if (isOfType(this.sender, QFontComboBox)) {
+        var fontFamily = value.family();
+        if (fontFamily.length===0) {
+            // font varies:
+            return;
+        }
+        value = fontFamily;
+    }
+
     // value comes from a combo box:
     else if (isComboBox(this.sender)) {
         // value is index of combo box:
         if (isNumber(value)) {
-            if (this.sender.itemData(value)===PropertyEditor.varies) {
+            var data = this.sender.itemData(value);
+            if (isNull(data)) {
+                // no data, use index as value:
+                this.propertyEditor.propertyChanged(this.propertyType, value);
                 return;
             }
-            this.propertyEditor.propertyChanged(this.propertyType,
-                                                this.sender.itemData(value));
+            if (data===PropertyEditor.varies) {
+                // value is *VARIES*, don't change anything:
+                return;
+            }
+            this.propertyEditor.propertyChanged(this.propertyType, data);
             return;
         }
 
@@ -79,7 +92,7 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
     }
 
     // value is string from a line edit (e.g. text contents):
-    else if (this.sender.toString()==="QLineEdit") {
+    else if (isOfType(this.sender, QLineEdit)) {
         value = this.sender.text;
         if (value===PropertyEditor.varies) {
             return;
@@ -87,7 +100,7 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
     }
 
     // value is number from a math line edit:
-    else if (this.sender.toString().startsWith("RMathLineEdit")) {
+    else if (isOfType(this.sender, RMathLineEdit)) {
         if (this.sender.text===this.sender.originalText) {
             return;
         }
@@ -98,12 +111,12 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
             return;
         }
         if (this.sender.isInteger()) {
-            typeHint = 2;
+            typeHint = RS.Int;
         }
     }
 
     // value is number from a math combo box:
-    else if (this.sender.toString().startsWith("RMathComboBox")) {
+    else if (isOfType(this.sender, RMathComboBox)) {
         if (this.sender.currentText===this.sender.originalText) {
             return;
         }
@@ -124,7 +137,13 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
  * that match the current entity type filter.
  */
 PropertyWatcher.prototype.propertyRemoved = function() {
-    this.propertyEditor.propertyChanged(this.propertyType, null);
+    if (RSettings.getQtVersion() >= 0x060000) {
+        this.propertyEditor.propertyChanged(this.propertyType, new QVariant());
+    }
+    else {
+        this.propertyEditor.propertyChanged(this.propertyType, null);
+    }
+
     this.propertyEditor.onlyChangesOverride = false;
 };
 
@@ -222,20 +241,15 @@ function PropertyEditorImpl(basePath) {
     this.widget.findChild("LabelProtected").text = RSettings.translate("REntity", "Protected") + this.colon;
 
     var selectionCombo = this.widget.findChild("Selection");
-    if (RSettings.isQt(6)) {
-        selectionCombo["activated(int)"].connect(this.filterChanged);
-    }
-    else {
-        selectionCombo["activated(int)"].connect(this, "filterChanged");
-    }
+    selectionCombo["activated(int)"].connect(this, this.filterChanged);
     selectionCombo.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
     selectionCombo.focusPolicy = Qt.ClickFocus;
 
     // initialize fixed general properties at the top:
     var layerCombo = this.widget.findChild("Layer");
     if (RSettings.isQt(6)) {
-        layerCombo.textActivated.connect(
-                    new PropertyWatcher(this, layerCombo, REntity.PropertyLayer).propertyChanged);
+        var pw = new PropertyWatcher(this, layerCombo, REntity.PropertyLayer);
+        layerCombo.textActivated.connect(pw, pw.propertyChanged);
     }
     else {
         layerCombo['activated(QString)'].connect(
@@ -248,8 +262,8 @@ function PropertyEditorImpl(basePath) {
 
     var colorCombo = this.widget.findChild("Color");
     if (RSettings.isQt(6)) {
-        colorCombo['activated(int)'].connect(
-                    new PropertyWatcher(this, colorCombo, REntity.PropertyColor).propertyChanged);
+        var pw = new PropertyWatcher(this, colorCombo, REntity.PropertyColor);
+        colorCombo['activated(int)'].connect(pw, pw.propertyChanged);
     }
     else {
         colorCombo['activated(int)'].connect(
@@ -261,8 +275,8 @@ function PropertyEditorImpl(basePath) {
 
     var lineweightCombo = this.widget.findChild("Lineweight");
     if (RSettings.isQt(6)) {
-        lineweightCombo['activated(int)'].connect(
-                    new PropertyWatcher(this, lineweightCombo, REntity.PropertyLineweight).propertyChanged);
+        var pw = new PropertyWatcher(this, lineweightCombo, REntity.PropertyLineweight);
+        lineweightCombo['activated(int)'].connect(pw, pw.propertyChanged);
     }
     else {
         lineweightCombo['activated(int)'].connect(
@@ -274,8 +288,8 @@ function PropertyEditorImpl(basePath) {
 
     var linetypeCombo = this.widget.findChild("Linetype");
     if (RSettings.isQt(6)) {
-        linetypeCombo['activated(int)'].connect(
-                    new PropertyWatcher(this, linetypeCombo, REntity.PropertyLinetype).propertyChanged);
+        var pw = new PropertyWatcher(this, linetypeCombo, REntity.PropertyLinetype);
+        linetypeCombo['activated(int)'].connect(pw, pw.propertyChanged);
     }
     else {
         linetypeCombo['activated(int)'].connect(
@@ -304,8 +318,8 @@ function PropertyEditorImpl(basePath) {
 
     var linetypeScaleEdit = this.widget.findChild("LinetypeScale");
     if (RSettings.isQt(6)) {
-        linetypeScaleEdit.editingFinished.connect(
-                    new PropertyWatcher(this, linetypeScaleEdit, REntity.PropertyLinetypeScale).propertyChanged);
+        var pw = new PropertyWatcher(this, linetypeScaleEdit, REntity.PropertyLinetypeScale);
+        linetypeScaleEdit.editingFinished.connect(pw, pw.propertyChanged);
     }
     else {
         linetypeScaleEdit.editingFinished.connect(
@@ -316,8 +330,8 @@ function PropertyEditorImpl(basePath) {
 
     var drawOrderEdit = this.widget.findChild("DrawOrder");
     if (RSettings.isQt(6)) {
-        drawOrderEdit.editingFinished.connect(
-                    new PropertyWatcher(this, drawOrderEdit, REntity.PropertyDrawOrder).propertyChanged);
+        var pw = new PropertyWatcher(this, drawOrderEdit, REntity.PropertyDrawOrder);
+        drawOrderEdit.editingFinished.connect(pw, pw.propertyChanged);
     }
     else {
         drawOrderEdit.editingFinished.connect(
@@ -355,15 +369,15 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
     this.widget.updatesEnabled = false;
     if (!onlyChanges) {
         if (!isNull(this.geometryGroup)) {
-            this.geometryGroup.destroy();
+            destr(this.geometryGroup);
             this.geometryGroup = undefined;
         }
         if (!isNull(this.childGroup)) {
-            this.childGroup.destroy();
+            destr(this.childGroup);
             this.childGroup = undefined;
         }
         if (!isNull(this.customGroup)) {
-            this.customGroup.destroy();
+            destr(this.customGroup);
             this.customGroup = undefined;
         }
     }
@@ -432,6 +446,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
         gridLayoutGeometry = new QGridLayout(this.geometryGroup);
         gridLayoutGeometry.setVerticalSpacing(2);
         gridLayoutGeometry.setHorizontalSpacing(2);
+        gridLayoutGeometry.setContentsMargins(6,6,6,6);
         // label:
         gridLayoutGeometry.setColumnStretch(0,0);
         // control:
@@ -462,6 +477,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
         if (RSettings.isXDataEnabled()) {
             // create custom property group box with grid layout:
             this.customGroup = new QGroupBox(qsTr("Custom"), this.widget);
+            //this.customGroup.objectName = "CustomGroup";
             layout.insertWidget(4, this.customGroup);
 
             // grid layout with four columns and N rows for N property controls:
@@ -496,11 +512,16 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
             var children = groupToClear.children();
             for (var i=0; i<children.length; i++) {
                 var child = children[i];
+                if (isNull(child)) {
+                    // don't destroy wrapper attached to the group box (QGroupBox_Wrapper):
+                    continue;
+                }
                 if (isOfType(child, QGridLayout)) {
                     // don't destroy layout:
                     continue;
                 }
-                children[i].destroy();
+
+                destr(child);
             }
         }
     }
@@ -519,10 +540,11 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
         var titles = this.getPropertyTitles(group);
         for (var pi=0; pi<titles.length; ++pi) {
             var title = titles[pi];
-            //qDebug("title: ", title);
+            //qDebug("  title: ", title);
 
             var value = this.getPropertyValue(group, title);
-            //qDebug("value: ", value);
+
+            //qDebug("    value: ", value);
 
             var attributes = this.getPropertyAttributes(group, title);
             //var propertyTypeId = attributes.getPropertyTypeId();
@@ -742,9 +764,8 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                             removeCustomPropertyButton.objectName = "DeleteCustomProperty" + name;
                             //qDebug("adding button to remove custom property named: ", name);
                             var propertyEditor = this;
-                            removeCustomPropertyButton.clicked.connect(
-                                        new PropertyWatcher(this, removeCustomPropertyButton, propertyTypeId),
-                                        'propertyRemoved');
+                            var pw = new PropertyWatcher(this, removeCustomPropertyButton, propertyTypeId);
+                            removeCustomPropertyButton.clicked.connect(pw, pw.propertyRemoved);
                             gridLayoutCustom.addWidget(removeCustomPropertyButton, row,3);
                         }
 
@@ -832,7 +853,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
             addCustomPropertyButton.iconSize = new QSize(12,12);
             addCustomPropertyButton.toolTip = qsTr("Add custom property to selected objects");
             addCustomPropertyButton.objectName = "AddCustomProperty";
-            addCustomPropertyButton.clicked.connect(this, "addCustomProperty");
+            addCustomPropertyButton.clicked.connect(this, this.addCustomProperty);
             gridLayoutCustom.addWidget(addCustomPropertyButton, gridLayoutCustom.rowCount(),3, 1,1);
         }
     }
@@ -877,7 +898,7 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
         requestAllButton.objectName = objectName + "_request";
         requestAllButton.text = qsTr("Show");
         requestAllButton.toolTip = qsTr("Show all properties");
-        requestAllButton.clicked.connect(this, "requestAllProperties");
+        requestAllButton.clicked.connect(this, this.requestAllProperties);
         requestAllButton.setSizePolicy(QSizePolicy.Ignored, QSizePolicy.Preferred);
 
         return new Array(requestAllButton);
@@ -893,25 +914,25 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
     //else
     if (propertyTypeId.getId()===RTextEntity.PropertyHAlign.getId()) {
         controls = this.initChoiceControls(
-                    objectName, propertyTypeId, onlyChanges, control, false, true);
+                    objectName, propertyTypeId, onlyChanges, control, [], []);
     }
 
     // Vertical alignment: combo box:
     else if (propertyTypeId.getId()===RTextEntity.PropertyVAlign.getId()) {
         controls = this.initChoiceControls(
-                    objectName, propertyTypeId, onlyChanges, control, false, true);
+                    objectName, propertyTypeId, onlyChanges, control, [], []);
     }
 
     // Polyline orientation: combo box:
     else if (propertyTypeId.getId()===RPolylineEntity.PropertyOrientation.getId()) {
         controls = this.initChoiceControls(
-                    objectName, propertyTypeId, onlyChanges, control, false, true);
+                    objectName, propertyTypeId, onlyChanges, control, [], []);
     }
 
     // Arc dimension arc symbol type: combo box:
     else if (propertyTypeId.getId()===RDimArcLengthEntity.PropertyDimArcSymbolType.getId()) {
         controls = this.initChoiceControls(
-                    objectName, propertyTypeId, onlyChanges, control, false, true);
+                    objectName, propertyTypeId, onlyChanges, control, [], []);
     }
 
     // DIMLUNIT: combo box with DIMLUNIT choices:
@@ -924,7 +945,7 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
              propertyTypeId.getId()===RDimensionEntity.PropertyDimazin.getId() ||
              propertyTypeId.getId()===RDimensionEntity.PropertyDimadec.getId()) {
         controls = this.initChoiceControls(
-                    objectName, propertyTypeId, onlyChanges, control, false, true);
+                    objectName, propertyTypeId, onlyChanges, control, [], []);
     }
 
     else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimdsep.getId()) {
@@ -979,7 +1000,8 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
                 }
                 indexControl.setProperty('controlNames', a);
 
-                indexControl["valueChanged(int)"].connect(new IndexWatcher(this, indexControl, propertyTypeId), "indexChanged");
+                var iw = new IndexWatcher(this, indexControl, propertyTypeId)
+                indexControl["valueChanged(int)"].connect(iw, iw.indexChanged);
             }
             else {
                 // make sure that the values for the current list index are updated:
@@ -1001,7 +1023,12 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
 
     // Choices: combo box:
     else if (attributes.hasChoices() || isComboBox(control)) {
-        controls = this.initChoiceControls(objectName, propertyTypeId, onlyChanges, control);
+        if (attributes.getStoreIndex()) {
+            controls = this.initChoiceControls(objectName, propertyTypeId, onlyChanges, control, undefined, []);
+        }
+        else {
+            controls = this.initChoiceControls(objectName, propertyTypeId, onlyChanges, control);
+        }
     }
 
     // String: line edit:
@@ -1043,6 +1070,10 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
 PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyTypeId, onlyChanges, control, index) {
     var document = EAction.getDocument();
 
+    if (isNull(document)) {
+        return;
+    }
+
     var value = this.getAdjustedPropertyValue(propertyTypeId);
     if (isNumber(index)) {
         value = value[index];
@@ -1154,9 +1185,9 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
         else {
             lineEdit = control;
         }
-        lineEdit.editingFinished.connect(
-                    new PropertyWatcher(this, control, propertyTypeId),
-                    'propertyChanged');
+
+        var pw = new PropertyWatcher(this, control, propertyTypeId);
+        lineEdit.editingFinished.connect(pw, pw.propertyChanged);
     }
 
     // move cursor to start if field is not being edited:
@@ -1215,9 +1246,8 @@ PropertyEditorImpl.prototype.initStringControls = function(objectName, propertyT
     }
 
     if (!onlyChanges) {
-        control.editingFinished.connect(
-                    new PropertyWatcher(this, control, propertyTypeId),
-                    'propertyChanged');
+        var pw = new PropertyWatcher(this, control, propertyTypeId);
+        control.editingFinished.connect(pw, pw.propertyChanged);
     }
 
     // move cursor to start if field is not being edited:
@@ -1276,9 +1306,8 @@ PropertyEditorImpl.prototype.initBooleanControls = function(objectName, property
     }
 
     if (!onlyChanges) {
-        control['activated(int)'].connect(
-                    new PropertyWatcher(this, control, propertyTypeId),
-                    'propertyChanged');
+        var pw = new PropertyWatcher(this, control, propertyTypeId);
+        control['activated(int)'].connect(pw, pw.propertyChanged);
     }
 
     return new Array(control);
@@ -1290,7 +1319,7 @@ PropertyEditorImpl.prototype.initBooleanControls = function(objectName, property
  */
 PropertyEditorImpl.prototype.initChoiceControls = function(
     objectName, propertyTypeId, onlyChanges, control, choices, choicesData) {
-    
+
     var i;
 
     var value = this.getAdjustedPropertyValue(propertyTypeId);
@@ -1308,6 +1337,9 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
             control.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
             control.focusPolicy = Qt.ClickFocus;
             initFontComboBox(control);
+            control.objectName = objectName;
+            var pw = new PropertyWatcher(this, control, propertyTypeId);
+            control.currentFontChanged.connect(pw, pw.propertyChanged);
         }
         else {
             control = new QComboBox(this.geometryGroup);
@@ -1315,30 +1347,47 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
             control.focusPolicy = Qt.ClickFocus;
             control.minimumWidth = 50;
             control.setSizePolicy(QSizePolicy.Ignored, QSizePolicy.Preferred);
+
+            control.objectName = objectName;
+
+            if (isNull(choicesData)/* && propertyTypeId.getId()!==REntity.PropertyLayer.getId()*/) {
+                var pw = new PropertyWatcher(this, control, propertyTypeId);
+                if (RSettings.getQtVersion() >= 0x060000) {
+                    control.textActivated.connect(pw, pw.propertyChanged);
+                    //control.currentTextChanged.connect(pw, pw.propertyChanged);
+                }
+                else {
+                    control['activated(QString)'].connect(pw, pw.propertyChanged);
+                }
+            }
+            else {
+                var pw = new PropertyWatcher(this, control, propertyTypeId);
+                if (RSettings.getQtVersion() >= 0x060000) {
+                    control.activated.connect(pw, pw.propertyChanged);
+                    //control.currentIndexChanged.connect(pw, pw.propertyChanged);
+                }
+                else {
+                    control['activated(int)'].connect(pw, pw.propertyChanged);
+                }
+            }
         }
 
-        control.objectName = objectName;
-
-        if (isNull(choicesData)/* && propertyTypeId.getId()!==REntity.PropertyLayer.getId()*/) {
-            control['activated(QString)'].connect(
-                        new PropertyWatcher(this, control, propertyTypeId),
-                        'propertyChanged');
-        }
-        else {
-            control['activated(int)'].connect(
-                        new PropertyWatcher(this, control, propertyTypeId),
-                        'propertyChanged');
-        }
     }
 
+    //var signalsBlocked;
+
     if (propertyTypeId.getId()===REntity.PropertyLayer.getId()) {
         WidgetFactory.initLayerCombo(control, EAction.getDocument());
     }
     else if (propertyTypeId.getId()===RTextEntity.PropertyHAlign.getId()) {
+        //signalsBlocked = control.blockSignals(true);
         WidgetFactory.initHAlignCombo(control);
+        //control.blockSignals(signalsBlocked);
     }
     else if (propertyTypeId.getId()===RTextEntity.PropertyVAlign.getId()) {
+        //signalsBlocked = control.blockSignals(true);
         WidgetFactory.initVAlignCombo(control);
+        //control.blockSignals(signalsBlocked);
     }
     else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimlunit.getId()) {
         WidgetFactory.initDimlunitCombo(control);
@@ -1376,8 +1425,17 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
                 control.addItems(cs);
             }
             else {
-                control.addItems(attributes.getChoices());
-                control.model().sort(0);
+                if (isNull(choicesData)) {
+                    control.addItems(attributes.getChoices());
+                    control.model().sort(0);
+                }
+                else {
+                    var ch = attributes.getChoices();
+                    for (i=0; i<ch.length; ++i) {
+                        // use choicesData as data of index if choicesData is empty:
+                        control.addItem(ch[i], isNull(choicesData[i]) ? i : choicesData[i]);
+                    }
+                }
             }
         }
         else {
@@ -1410,17 +1468,26 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
         control.removeItem(variesIndex);
     }
 
+    // find out index of combo box for the given value:
     var index = -1;
     if (typeof(value)==="string") {
         index = control.findText(value);
         if (index===-1) {
-            control.addItem(value);
-            index = control.findText(value);
+            var i = parseInt(value);
+            if (!isNaN(i) && i>=0 && i<control.count) {
+                // value is the index of the combo box as string (from custom property of custom entity):
+                index = i;
+            }
+            else {
+                control.addItem(value);
+                index = control.findText(value);
+            }
         }
     }
     else {
         for (i=0; i<control.count; ++i) {
             var data = control.itemData(i);
+
             var match = false;
 
             // for some types (e.g. RColor, RLinetype), we have to use equals here:
@@ -1464,7 +1531,15 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
         }
     }
     else {
+        var signalsBlocked = control.blockSignals(true);
+
         control.currentIndex = index;
+        control.blockSignals(signalsBlocked);
+
+        if (isOfType(control, RColorCombo)) {
+            // make sure color combo is aware of current (custom) color:
+            control.setColor(value);
+        }
     }
 
     return [ control ];
@@ -1498,7 +1573,7 @@ PropertyEditorImpl.prototype.filterChanged = function() {
         entityTypeFilter = RS.EntityAll;
     }
 
-    this.updateFromDocument(doc, false, entityTypeFilter, true);
+    this.updateFromDocumentNow(doc, false, entityTypeFilter, true);
 };
 
 /**
@@ -1516,7 +1591,7 @@ PropertyEditorImpl.prototype.requestAllProperties = function() {
         entityTypeFilter = RS.EntityAll;
     }
 
-    this.updateFromDocument(doc, false, entityTypeFilter, true, true);
+    this.updateFromDocumentNow(doc, false, entityTypeFilter, true, true);
 };
 
 PropertyEditorImpl.prototype.getAdjustedPropertyValue = function(propertyTypeId) {
@@ -1540,13 +1615,16 @@ PropertyEditorImpl.prototype.makeReadOnly = function(control) {
         return;
     }
 
+    RPropertyEditor.makeReadOnly(control, true);
+
+    /*
     var p = control.palette;
-    if (isNull(control.oriPalette)) {
+    if (isNull(control.property("oriPalette"))) {
         control.setProperty("oriPalette", control.palette);
     }
 
-    p.setColor(QPalette.Active, QPalette.Text, control.oriPalette.color(QPalette.Disabled, QPalette.WindowText));
-    p.setColor(QPalette.Inactive, QPalette.Text, control.oriPalette.color(QPalette.Disabled, QPalette.WindowText));
+    p.setColor(QPalette.Active, QPalette.Text, control.property("oriPalette").color(QPalette.Disabled, QPalette.WindowText));
+    p.setColor(QPalette.Inactive, QPalette.Text, control.property("oriPalette").color(QPalette.Disabled, QPalette.WindowText));
 
 //    if (RSettings.hasDarkGuiBackground()) {
 //        p.setColor(QPalette.Base, new QColor("#0a0a0a"));
@@ -1555,8 +1633,9 @@ PropertyEditorImpl.prototype.makeReadOnly = function(control) {
 //        p.setColor(QPalette.Base, new QColor("#eeeeee"));
 //    }
     control.palette = p;
+    */
 
-    control.readOnly = true;
+    //control.readOnly = true;
     // leave enabled to allow copy / page (20140411):
     //control.enabled = false;
 };
@@ -1569,22 +1648,25 @@ PropertyEditorImpl.prototype.makeReadWrite = function(control) {
         return;
     }
 
-    var p = control.palette;
-    if (isNull(control.oriPalette)) {
-        control.setProperty("oriPalette", control.palette);
-    }
+    RPropertyEditor.makeReadOnly(control, false);
 
-    p.setColor(QPalette.Active, QPalette.Text, control.oriPalette.color(QPalette.Active, QPalette.WindowText));
-    p.setColor(QPalette.Inactive, QPalette.Text, control.oriPalette.color(QPalette.Inactive, QPalette.WindowText));
-//    //if (RSettings.hasDarkGuiBackground()) {
-//        p.setColor(QPalette.Base, control.oriBase);
-////    }
-////    else {
-////        p.setColor(QPalette.Base, new QColor("#ffffff"));
-////    }
-    control.palette = p;
+//    var p = control.palette;
+//    if (isNull(control.property("oriPalette"))) {
+//        control.setProperty("oriPalette", control.palette);
+//    }
+
+//    p.setColor(QPalette.Active, QPalette.Text, control.property("oriPalette").color(QPalette.Active, QPalette.WindowText));
+//    p.setColor(QPalette.Inactive, QPalette.Text, control.property("oriPalette").color(QPalette.Inactive, QPalette.WindowText));
+////    //if (RSettings.hasDarkGuiBackground()) {
+////        p.setColor(QPalette.Base, control.oriBase);
+//////    }
+//////    else {
+//////        p.setColor(QPalette.Base, new QColor("#ffffff"));
+//////    }
+//    control.palette = p;
+
+    //control.readOnly = false;
 
-    control.readOnly = false;
     control.enabled = true;
 };
 
@@ -1595,8 +1677,7 @@ PropertyEditorImpl.prototype.addCustomProperty = function() {
     buttonBox.button(QDialogButtonBox.Ok).enabled = false;
 
     var nameEdit = dialog.findChild("Name");
-    var rx = new RegExp("[^<>\\\\\":;\?\*|,=`]{1,255}");
-    var validator = new QRegExpValidator(rx, nameEdit);
+    var validator = createValidator("[^<>\\\\\":;\?\*|,=`]{1,255}", nameEdit);
     nameEdit.setValidator(validator);
     nameEdit.textChanged.connect(
         function(text) {
@@ -1607,7 +1688,7 @@ PropertyEditorImpl.prototype.addCustomProperty = function() {
     var valueEdit = dialog.findChild("Value");
 
     if (!dialog.exec()) {
-        dialog.destroy();
+        destrDialog(dialog);
         EAction.activateMainWindow();
         return;
     }
@@ -1619,7 +1700,7 @@ PropertyEditorImpl.prototype.addCustomProperty = function() {
     this.propertyChanged(new RPropertyTypeId(RSettings.getAppId(), name), value, this.getEntityTypeFilter());
     this.onlyChangesOverride = false;
 
-    dialog.destroy();
+    destrDialog(dialog);
     EAction.activateMainWindow();
 };
 
@@ -1637,6 +1718,32 @@ PropertyEditor.getPreferencesCategory = function() {
     return [ qsTr("Widgets"), qsTr("Property Editor") ];
 };
 
+PropertyEditor.initPreferences = function(pageWidget, calledByPrefDialog, document) {
+    var w = pageWidget.findChild("Decimals");
+    w.addItem("0", 0);
+    w.addItem("1 (1/2)", 1);
+    w.addItem("2 (1/4)", 2);
+    w.addItem("3 (1/8)", 3);
+    w.addItem("4 (1/16)", 4);
+    w.addItem("5 (1/32)", 5);
+    w.addItem("6 (1/64)", 6);
+    w.addItem("7 (1/128)", 7);
+    w.addItem("8 (1/256)", 8);
+    w.currentIndex = 8;
+
+    // hide Qt 6 only options:
+    if (RSettings.getQtVersion() < 0x060000) {
+        var widgets = ["LazyUpdate", "LazyUpdateDelay_Label", "LazyUpdateDelay"];
+        for (var i=0; i<widgets.length; i++) {
+            w = pageWidget.findChild(widgets[i]);
+            if (!isNull(w)) {
+                w.visible = false;
+            }
+        }
+
+    }
+};
+
 PropertyEditor.applyPreferences = function(doc, mdiChild) {
     var appWin = RMainWindowQt.getMainWindow();
     appWin.notifyPropertyListeners(EAction.getDocument());
@@ -1650,7 +1757,7 @@ PropertyEditor.prototype.beginEvent = function() {
 
     var appWin = RMainWindowQt.getMainWindow();
     var dock = appWin.findChild("PropertyEditorDock");
-    if (!QCoreApplication.arguments().contains("-no-show")) {
+    if (!RSettings.getOriginalArguments().contains("-no-show")) {
         dock.visible = !dock.visible;
         if (dock.visible) dock.raise();
     }
@@ -1694,7 +1801,6 @@ PropertyEditor.init = function(basePath) {
     var action = new RGuiAction(qsTr("Property Editor"), appWin);
     action.setRequiresDocument(false);
     action.setScriptFile(basePath + "/PropertyEditor.js");
-    action.setIcon(basePath + "/PropertyEditor.svg");
     action.setDefaultShortcut(new QKeySequence("g,p"));
     action.setDefaultCommands(["gp"]);
     action.setGroupSortOrder(3700);
@@ -1706,7 +1812,7 @@ PropertyEditor.init = function(basePath) {
     dock.objectName = "PropertyEditorDock";
     dock.setWidget(pe.widget);
     appWin.addPropertyListener(pe);
-    if (RSettings.isQt(6)) {
+    if (RSettings.getQtVersion() >= 0x060000) {
         appWin.addLayerListener(pe);
     }
     else {
