@@ -238,7 +238,7 @@
 <context>
     <name>REntity</name>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+67"/>
+        <location filename="../src/core/RBlock.cpp" line="+73"/>
         <location filename="../src/core/RLayer.cpp" line="+95"/>
         <location filename="../src/core/RLayerState.cpp" line="+46"/>
         <location filename="../src/core/RLayout.cpp" line="+81"/>
@@ -264,7 +264,7 @@
     </message>
     <message>
         <location line="-2"/>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+99"/>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
         <location line="+3"/>
         <location filename="../src/core/RLayout.cpp" line="+2"/>
         <location line="+3"/>
@@ -320,7 +320,12 @@
         <translation>Owned by Reference</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceData.cpp" line="+886"/>
+        <location line="+1"/>
+        <source>External reference</source>
+        <translation>External reference</translation>
+    </message>
+    <message>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
         <source>Circular (recursive) block referencing detected:</source>
         <translation>Circular (recursive) block referencing detected:</translation>
     </message>
@@ -335,10 +340,15 @@
         <translation>Block</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-6"/>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
         <source>Referenced Block</source>
         <translation>Referenced Block</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>External Reference</source>
+        <translation>External Reference</translation>
+    </message>
     <message>
         <location line="+1"/>
         <location line="+1"/>
@@ -1055,6 +1065,21 @@
         <source>Fenceline 2</source>
         <translation>Fenceline 2</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 1</source>
+        <translation>Point 1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 2</source>
+        <translation>Point 2</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Plant</source>
+        <translation>Plant</translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Water</source>
