@@ -282,7 +282,7 @@
         <location line="+1"/>
         <source>Sweep Angle</source>
         <translatorcomment>A megrajzolt ív hossza</translatorcomment>
-        <translation></translation>
+        <translation>Ívszög</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -305,19 +305,19 @@
         <location filename="../src/entity/RAttributeEntity.cpp" line="+101"/>
         <source>Tag</source>
         <translatorcomment>The ID of a block attribute, for example &quot;author_name&quot;.</translatorcomment>
-        <translation></translation>
+        <translation>Címke</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Prompt</source>
         <translatorcomment>The label of a block attribute, what the user sees, for example &quot;Author name&quot;</translatorcomment>
-        <translation></translation>
+        <translation>Kérdés</translation>
     </message>
     <message>
         <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
         <source>Circumference</source>
         <translatorcomment>Kör kerülete</translatorcomment>
-        <translation></translation>
+        <translation>Kerület</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
@@ -346,7 +346,7 @@
         <location line="+1"/>
         <source>Line 1 Start</source>
         <translatorcomment>Szög méretvonalának darabja</translatorcomment>
-        <translation></translation>
+        <translation>1. vonal eleje</translation>
     </message>
     <message>
         <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
@@ -413,7 +413,7 @@
         <location line="+1"/>
         <source>Defining Point</source>
         <translatorcomment>Ennek a pontnak írja ki az ordináta &quot;méretvonal&quot; az egyik koordinátájtát (abszcisszát(X) vagy ordinátát(Y))</translatorcomment>
-        <translation></translation>
+        <translation>Meghatározó pont</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -454,7 +454,7 @@
         <location line="+1"/>
         <source>Definition Point</source>
         <translatorcomment>An important point of a dimension, can be at different locations depending on the dimension type hence probably the vague name.</translatorcomment>
-        <translation></translation>
+        <translation>Definíciós pont</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -559,7 +559,7 @@
         <location line="+1"/>
         <source>Winding</source>
         <translatorcomment>A fill mode in which double-filled areas are also filled, not empty.</translatorcomment>
-        <translation></translation>
+        <translation>Tekercselés</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -650,14 +650,14 @@
         <location line="+1"/>
         <source>U</source>
         <translatorcomment>A vector indicting the direction of the image bottom side (commonly called U vector).</translatorcomment>
-        <translation></translation>
+        <translation>U</translation>
     </message>
     <message>
         <location line="+2"/>
         <location line="+1"/>
         <source>V</source>
         <translatorcomment>A vector indicting the direction of the image left side (commonly called V vector).</translatorcomment>
-        <translation></translation>
+        <translation>V</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -824,7 +824,7 @@
         <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
         <source>Closed Periodic</source>
         <translatorcomment>Spline esetén a körbezártság</translatorcomment>
-        <translation></translation>
+        <translation>Zárt periodikus</translation>
     </message>
     <message>
         <location line="+1"/>
